package com.DartChecker;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.os.Build;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.SwitchCompat;
import androidx.constraintlayout.widget.ConstraintLayout;

import android.os.Bundle;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import java.util.ArrayList;
import java.util.Locale;

public class einstellungen extends AppCompatActivity {

    @Override
    protected void attachBaseContext(Context base) {
        super.attachBaseContext(updateBaseContextLocale(base));
    }

    private Context updateBaseContextLocale(Context context) {
        final SharedPreferences settings = context.getSharedPreferences("Einstellungen", 0);
        String language = Locale.getDefault().getLanguage();
        if (settings.contains("Sprache")) {
            language = settings.getString("Sprache", "en");
        }
        Locale locale = new Locale(language);
        Locale.setDefault(locale);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
            return updateResourcesLocale(context, locale);
        }

        return updateResourcesLocaleLegacy(context, locale);
    }

    @TargetApi(Build.VERSION_CODES.N_MR1)
    private Context updateResourcesLocale(Context context, Locale locale) {
        Configuration configuration = new Configuration(context.getResources().getConfiguration());
        configuration.setLocale(locale);
        return context.createConfigurationContext(configuration);
    }

    private Context updateResourcesLocaleLegacy(Context context, Locale locale) {
        Resources resources = context.getResources();
        Configuration configuration = resources.getConfiguration();
        configuration.locale = locale;
        resources.updateConfiguration(configuration, resources.getDisplayMetrics());
        return context;
    }


    @Override

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        final SharedPreferences settings = getSharedPreferences("Einstellungen", 0);
        SharedPreferences.Editor editor = settings.edit();

        boolean darktheme = true,
                stylecolor = true,
                slmode = true,
                inputmode = false,
                suddendeathmode = false,
                spielgehtweiter = false;
        if (settings.contains("Theme")) darktheme = settings.getBoolean("Theme", true);
        if (settings.contains("Style")) stylecolor = settings.getBoolean("Style", true);
        if (darktheme && stylecolor) setTheme(R.style.AppThemeBlack);
            else if (darktheme) setTheme(R.style.AppThemeDark);
                else setTheme(R.style.Theme_AppCompat_Light_NoActionBar);
        setContentView(R.layout.activity_einstellungen);
        ConstraintLayout main = findViewById(R.id.mainlayout);
        if (settings.contains("keepscreenonmenu")) main.setKeepScreenOn(settings.getBoolean("keepscreenonmenu",true));


        final SwitchCompat setmode = findViewById(R.id.slmode);
        final SwitchCompat themes = findViewById(R.id.themeswitch);
        final SwitchCompat style = findViewById(R.id.themeswitchsubcolor);
        TextView umschaltzeit = findViewById(R.id.millisekunden);
        final TextView dartanzahl = findViewById(R.id.dartanzahl);
        TextView crazystart = findViewById(R.id.crazystartsegment);
        final SwitchCompat inputmethode = findViewById(R.id.inputmethode);
        final SwitchCompat suddendeath = findViewById(R.id.suddendeath);
        final SwitchCompat spielgehtweiterswitch = findViewById(R.id.cricketkeinstop);
        final SwitchCompat undosicherheitsabfrage = findViewById(R.id.undosicherheit);
        final SwitchCompat keepsceenongame = findViewById(R.id.keepscreenongame);
        final SwitchCompat keepscreenonmenu = findViewById(R.id.keepscreenonmenu);
        final SwitchCompat playaudio = findViewById(R.id.playaudio);
        int anzahldarts = 0;

        if (settings.contains("crazystart"))
            crazystart.setText(String.format(Integer.toString(settings.getInt("crazystart", 6))));

        if (settings.contains("changetime"))
            umschaltzeit.setText(String.format(Integer.toString(settings.getInt("changetime", 1500))));

        if (settings.contains("setlegmodus")) slmode = settings.getBoolean("setlegmodus", true);
        setmode.setChecked(slmode);
        if (slmode) {
            setmode.setText(getResources().getString(R.string.setlegmodusfirstto));
        } else {
            setmode.setText(getResources().getString(R.string.setlegmodusbestof));
        }

        themes.setChecked(darktheme);
        if (darktheme) {
            themes.setText(getResources().getString(R.string.design_dunkel));
            style.setEnabled(true);
        } else {
            themes.setText(getResources().getString(R.string.design_hell));
            style.setEnabled(false);
        }

        style.setChecked(stylecolor);
        if (stylecolor) {
            style.setText(getResources().getString(R.string.subdesign_black));
        }
        else {
            style.setText(getResources().getString(R.string.subdesign_grey));
        }

        if (settings.contains("inputmethode"))
            inputmode = settings.getBoolean("inputmethode", false);
        inputmethode.setChecked(inputmode);
        if (inputmode) {
            inputmethode.setText(getResources().getString(R.string.inputmode3dart));
        } else {
            inputmethode.setText(getResources().getString(R.string.inputmode1dart));
        }

        if (settings.contains("suddendeath"))
            suddendeathmode = settings.getBoolean("suddendeath", false);
        suddendeath.setChecked(suddendeathmode);
        if (settings.contains("sddarts")) anzahldarts = settings.getInt("sddarts", 20);
        dartanzahl.setText(String.format(Integer.toString(anzahldarts)));
        dartanzahl.setEnabled(suddendeath.isChecked());
        if (settings.contains("spielgehtweiter"))
            spielgehtweiter = settings.getBoolean("spielgehtweiter", false);
        spielgehtweiterswitch.setChecked(spielgehtweiter);

        ArrayList<String> sprachen = new ArrayList<>();
        sprachen.add(getResources().getString(R.string.system));
        sprachen.add("Deutsch");
        sprachen.add("English");
        sprachen.add("Español");
        sprachen.add("Français");
        ArrayAdapter<String> arrayAdapter = new ArrayAdapter<>(
                einstellungen.this,
                R.layout.spinner_item_head, sprachen);
        arrayAdapter.setDropDownViewResource(R.layout.support_simple_spinner_dropdown_item);
        final Spinner spin1 = findViewById(R.id.sprache);
        spin1.setAdapter(arrayAdapter);

        ArrayList<String> segmente = new ArrayList<>();
        for (int i=0;i<=20;i++) {
            segmente.add(String.valueOf(i));
        }
        segmente.add("25");

        ArrayAdapter<String> arrayAdapterseg = new ArrayAdapter<>(
                einstellungen.this,
                R.layout.spinner_item_head, segmente);
        arrayAdapterseg.setDropDownViewResource(R.layout.support_simple_spinner_dropdown_item);
        final Spinner spin2 = findViewById(R.id.finishzahl);
        spin2.setAdapter(arrayAdapterseg);
        int cz=0;
        if (settings.contains("Checkoutzahl"))  cz = settings.getInt("Checkoutzahl",0);
        if (cz==25) spin2.setSelection(21); else spin2.setSelection(cz);  //index!=checkoutwunsch
        if (settings.contains("SprachZahl")) spin1.setSelection(settings.getInt("SprachZahl", 0));
        if (settings.contains("Undosicherheitsabfrage"))
            undosicherheitsabfrage.setChecked(settings.getBoolean("Undosicherheitsabfrage", false));
        if (settings.contains("keepscreenongame"))
            keepsceenongame.setChecked(settings.getBoolean("keepscreenongame",true));
        if (settings.contains("keepscreenonmenu"))
            keepscreenonmenu.setChecked(settings.getBoolean("keepscreenonmenu", false));
        if (settings.contains("playaudio")) playaudio.setChecked(settings.getBoolean("playaudio",true));

        spin2.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> adapterView, View view, int position, long l) {
                editor.putInt("Checkoutzahl", Integer.parseInt(spin2.getSelectedItem().toString()));
                editor.apply();
            }
            @Override
            public void onNothingSelected(AdapterView<?> adapterView) {
            }
        });

        spin1.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> parent, View v, int position, long id) {
                String language_code = "en";
                switch (position) {
                    case 0:
                        language_code = settings.getString("SystemSprache", language_code);
                        break;
                    case 1:
                        language_code = "de";
                        break;
                    case 2:
                        language_code = "en";
                        break;
                    case 3:
                        language_code = "es";
                        break;
                    case 4:
                        language_code = "fr";
                        break;
                }

                editor.putString("Sprache", language_code);
                editor.putInt("SprachZahl", position);
                editor.apply();
                if (settings.contains("Sprache")) {
                    if (!(language_code.equals(Locale.getDefault().getLanguage()))) {
                        // Sprache aktualisieren durch Neustart der activity
                        Intent intent = getIntent();
                        finish();
                        startActivity(intent);
                    }
                }

            }

            @Override
            public void onNothingSelected(AdapterView<?> AdapterView) {
            }

        });

        keepscreenonmenu.setOnCheckedChangeListener((compoundButton, b) -> {
            editor.putBoolean("keepscreenonmenu", keepscreenonmenu.isChecked());
            editor.apply();
        });

        keepsceenongame.setOnCheckedChangeListener((compoundButton, b) -> {
            editor.putBoolean("keepscreenongame", keepsceenongame.isChecked());
            editor.apply();
        });

        undosicherheitsabfrage.setOnCheckedChangeListener((buttonView, isChecked) -> {
            editor.putBoolean("Undosicherheitsabfrage", undosicherheitsabfrage.isChecked());
            editor.apply();
        });

        themes.setOnCheckedChangeListener((buttonView, isChecked) -> {
            if (isChecked) {
                themes.setText(getResources().getString(R.string.design_dunkel));
                style.setEnabled(true);
            } else {
                themes.setText(getResources().getString(R.string.design_hell));
                style.setEnabled(false);
            }
            editor.putBoolean("Theme", themes.isChecked());
            editor.apply();
            //einstellungsactivity neu starten
            Intent intent = getIntent();
            finish();
            startActivity(intent);
        });
        findViewById(R.id.appBarLayout).requestFocus();

        style.setOnCheckedChangeListener((compoundButton, b) -> {
            if (style.isChecked()) {
                style.setText(getResources().getString(R.string.subdesign_black));
            } else {
                style.setText(getResources().getString(R.string.subdesign_grey));
            }
            editor.putBoolean("Style", style.isChecked());
            editor.apply();
            Intent intent = getIntent();
            finish();
            startActivity(intent);
        });

        playaudio.setOnCheckedChangeListener((compoundButton, b) -> {
            editor.putBoolean("playaudio", playaudio.isChecked());
            editor.apply();
        });

        setmode.setOnCheckedChangeListener((buttonView, isChecked) -> {
            if (isChecked) {
                setmode.setText(getResources().getString(R.string.setlegmodusfirstto));
            } else setmode.setText(getResources().getString(R.string.setlegmodusbestof));

            editor.putBoolean("setlegmodus", setmode.isChecked());
            editor.apply();
        });

        inputmethode.setOnCheckedChangeListener((buttonView, isChecked) -> {
            if (isChecked) {
                inputmethode.setText(getResources().getString(R.string.inputmode3dart));
            } else inputmethode.setText(getResources().getString(R.string.inputmode1dart));

            editor.putBoolean("inputmethode", inputmethode.isChecked());
            editor.apply();
        });

        suddendeath.setOnCheckedChangeListener((buttonView, isChecked) -> {
            if (isChecked) {
                dartanzahl.setEnabled(true);
                Toast.makeText(getApplicationContext(), getResources().getString(R.string.suddendeathHinweis), Toast.LENGTH_LONG).show();
            } else dartanzahl.setEnabled(false);
            editor.putBoolean("suddendeath", suddendeath.isChecked());
            editor.apply();
        });

        spielgehtweiterswitch.setOnCheckedChangeListener((buttonView, isChecked) -> {
            editor.putBoolean("spielgehtweiter", spielgehtweiterswitch.isChecked());
            editor.apply();
        });

        final Button ok = findViewById(R.id.okb2);
        ok.setOnClickListener(v -> onBackPressed());


        crazystart.setOnEditorActionListener((v, actionId, event) -> {
            if (actionId == EditorInfo.IME_ACTION_DONE) {
                // eingabe zwischen 1 und 13?
                try {
                    if ((crazystart.getText().toString().isEmpty()) || (Integer.parseInt(crazystart.getText().toString()) < 1) || (Integer.parseInt(crazystart.getText().toString()) > 13) ) {
                        Toast.makeText(einstellungen.this, getResources().getString(R.string.range), Toast.LENGTH_LONG).show();
                        return true;
                    }
                } catch (Exception e) {
                    //größere eingabe als integer erlaubt
                }
            }
            return false;
        });

    }

    public void onBackPressed() {
        //safe number inputs
        TextView millisekunden = findViewById(R.id.millisekunden);
        TextView dartanzahl = findViewById(R.id.dartanzahl);
        TextView crazystart = findViewById(R.id.crazystartsegment);
        Spinner finishzahl = findViewById(R.id.finishzahl);
        SharedPreferences settings = getSharedPreferences("Einstellungen", 0);
        SharedPreferences.Editor editor = settings.edit();
        editor.putInt("changetime", Integer.parseInt(millisekunden.getText().toString()));
        editor.putInt("sddarts", Integer.parseInt(dartanzahl.getText().toString()));
        editor.putInt("crazystart", Integer.parseInt(crazystart.getText().toString()));
        editor.putInt("Checkoutzahl",Integer.parseInt(finishzahl.getSelectedItem().toString()));
        editor.apply();
        finish();
    }


}
